v1alpha1

package
v0.0.0-...-d5ff20c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 6, 2018 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

This package has the automatically generated typed clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RandomSecretExpansion

type RandomSecretExpansion interface{}

type RandomSecretInterface

type RandomSecretInterface interface {
	Create(*v1alpha1.RandomSecret) (*v1alpha1.RandomSecret, error)
	Update(*v1alpha1.RandomSecret) (*v1alpha1.RandomSecret, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.RandomSecret, error)
	List(opts v1.ListOptions) (*v1alpha1.RandomSecretList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.RandomSecret, err error)
	RandomSecretExpansion
}

RandomSecretInterface has methods to work with RandomSecret resources.

type RandomSecretsGetter

type RandomSecretsGetter interface {
	RandomSecrets(namespace string) RandomSecretInterface
}

RandomSecretsGetter has a method to return a RandomSecretInterface. A group's client should implement this interface.

type SecretsV1alpha1Client

type SecretsV1alpha1Client struct {
	// contains filtered or unexported fields
}

SecretsV1alpha1Client is used to interact with features provided by the secrets.k8s.captncraig.io group.

func New

New creates a new SecretsV1alpha1Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*SecretsV1alpha1Client, error)

NewForConfig creates a new SecretsV1alpha1Client for the given config.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *SecretsV1alpha1Client

NewForConfigOrDie creates a new SecretsV1alpha1Client for the given config and panics if there is an error in the config.

func (*SecretsV1alpha1Client) RESTClient

func (c *SecretsV1alpha1Client) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

func (*SecretsV1alpha1Client) RandomSecrets

func (c *SecretsV1alpha1Client) RandomSecrets(namespace string) RandomSecretInterface

func (*SecretsV1alpha1Client) VaultSecrets

func (c *SecretsV1alpha1Client) VaultSecrets(namespace string) VaultSecretInterface

type SecretsV1alpha1Interface

type SecretsV1alpha1Interface interface {
	RESTClient() rest.Interface
	RandomSecretsGetter
	VaultSecretsGetter
}

type VaultSecretExpansion

type VaultSecretExpansion interface{}

type VaultSecretInterface

type VaultSecretInterface interface {
	Create(*v1alpha1.VaultSecret) (*v1alpha1.VaultSecret, error)
	Update(*v1alpha1.VaultSecret) (*v1alpha1.VaultSecret, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.VaultSecret, error)
	List(opts v1.ListOptions) (*v1alpha1.VaultSecretList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.VaultSecret, err error)
	VaultSecretExpansion
}

VaultSecretInterface has methods to work with VaultSecret resources.

type VaultSecretsGetter

type VaultSecretsGetter interface {
	VaultSecrets(namespace string) VaultSecretInterface
}

VaultSecretsGetter has a method to return a VaultSecretInterface. A group's client should implement this interface.

Directories

Path Synopsis
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to