Documentation
¶
Overview ¶
Package fake has the automatically generated clients.
Index ¶
- type FakeRandomSecrets
- func (c *FakeRandomSecrets) Create(randomSecret *v1alpha1.RandomSecret) (result *v1alpha1.RandomSecret, err error)
- func (c *FakeRandomSecrets) Delete(name string, options *v1.DeleteOptions) error
- func (c *FakeRandomSecrets) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
- func (c *FakeRandomSecrets) Get(name string, options v1.GetOptions) (result *v1alpha1.RandomSecret, err error)
- func (c *FakeRandomSecrets) List(opts v1.ListOptions) (result *v1alpha1.RandomSecretList, err error)
- func (c *FakeRandomSecrets) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.RandomSecret, err error)
- func (c *FakeRandomSecrets) Update(randomSecret *v1alpha1.RandomSecret) (result *v1alpha1.RandomSecret, err error)
- func (c *FakeRandomSecrets) Watch(opts v1.ListOptions) (watch.Interface, error)
- type FakeSecretsV1alpha1
- type FakeVaultSecrets
- func (c *FakeVaultSecrets) Create(vaultSecret *v1alpha1.VaultSecret) (result *v1alpha1.VaultSecret, err error)
- func (c *FakeVaultSecrets) Delete(name string, options *v1.DeleteOptions) error
- func (c *FakeVaultSecrets) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
- func (c *FakeVaultSecrets) Get(name string, options v1.GetOptions) (result *v1alpha1.VaultSecret, err error)
- func (c *FakeVaultSecrets) List(opts v1.ListOptions) (result *v1alpha1.VaultSecretList, err error)
- func (c *FakeVaultSecrets) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.VaultSecret, err error)
- func (c *FakeVaultSecrets) Update(vaultSecret *v1alpha1.VaultSecret) (result *v1alpha1.VaultSecret, err error)
- func (c *FakeVaultSecrets) Watch(opts v1.ListOptions) (watch.Interface, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FakeRandomSecrets ¶
type FakeRandomSecrets struct {
Fake *FakeSecretsV1alpha1
// contains filtered or unexported fields
}
FakeRandomSecrets implements RandomSecretInterface
func (*FakeRandomSecrets) Create ¶
func (c *FakeRandomSecrets) Create(randomSecret *v1alpha1.RandomSecret) (result *v1alpha1.RandomSecret, err error)
Create takes the representation of a randomSecret and creates it. Returns the server's representation of the randomSecret, and an error, if there is any.
func (*FakeRandomSecrets) Delete ¶
func (c *FakeRandomSecrets) Delete(name string, options *v1.DeleteOptions) error
Delete takes name of the randomSecret and deletes it. Returns an error if one occurs.
func (*FakeRandomSecrets) DeleteCollection ¶
func (c *FakeRandomSecrets) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeRandomSecrets) Get ¶
func (c *FakeRandomSecrets) Get(name string, options v1.GetOptions) (result *v1alpha1.RandomSecret, err error)
Get takes name of the randomSecret, and returns the corresponding randomSecret object, and an error if there is any.
func (*FakeRandomSecrets) List ¶
func (c *FakeRandomSecrets) List(opts v1.ListOptions) (result *v1alpha1.RandomSecretList, err error)
List takes label and field selectors, and returns the list of RandomSecrets that match those selectors.
func (*FakeRandomSecrets) Patch ¶
func (c *FakeRandomSecrets) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.RandomSecret, err error)
Patch applies the patch and returns the patched randomSecret.
func (*FakeRandomSecrets) Update ¶
func (c *FakeRandomSecrets) Update(randomSecret *v1alpha1.RandomSecret) (result *v1alpha1.RandomSecret, err error)
Update takes the representation of a randomSecret and updates it. Returns the server's representation of the randomSecret, and an error, if there is any.
func (*FakeRandomSecrets) Watch ¶
func (c *FakeRandomSecrets) Watch(opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested randomSecrets.
type FakeSecretsV1alpha1 ¶
func (*FakeSecretsV1alpha1) RESTClient ¶
func (c *FakeSecretsV1alpha1) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*FakeSecretsV1alpha1) RandomSecrets ¶
func (c *FakeSecretsV1alpha1) RandomSecrets(namespace string) v1alpha1.RandomSecretInterface
func (*FakeSecretsV1alpha1) VaultSecrets ¶
func (c *FakeSecretsV1alpha1) VaultSecrets(namespace string) v1alpha1.VaultSecretInterface
type FakeVaultSecrets ¶
type FakeVaultSecrets struct {
Fake *FakeSecretsV1alpha1
// contains filtered or unexported fields
}
FakeVaultSecrets implements VaultSecretInterface
func (*FakeVaultSecrets) Create ¶
func (c *FakeVaultSecrets) Create(vaultSecret *v1alpha1.VaultSecret) (result *v1alpha1.VaultSecret, err error)
Create takes the representation of a vaultSecret and creates it. Returns the server's representation of the vaultSecret, and an error, if there is any.
func (*FakeVaultSecrets) Delete ¶
func (c *FakeVaultSecrets) Delete(name string, options *v1.DeleteOptions) error
Delete takes name of the vaultSecret and deletes it. Returns an error if one occurs.
func (*FakeVaultSecrets) DeleteCollection ¶
func (c *FakeVaultSecrets) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeVaultSecrets) Get ¶
func (c *FakeVaultSecrets) Get(name string, options v1.GetOptions) (result *v1alpha1.VaultSecret, err error)
Get takes name of the vaultSecret, and returns the corresponding vaultSecret object, and an error if there is any.
func (*FakeVaultSecrets) List ¶
func (c *FakeVaultSecrets) List(opts v1.ListOptions) (result *v1alpha1.VaultSecretList, err error)
List takes label and field selectors, and returns the list of VaultSecrets that match those selectors.
func (*FakeVaultSecrets) Patch ¶
func (c *FakeVaultSecrets) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.VaultSecret, err error)
Patch applies the patch and returns the patched vaultSecret.
func (*FakeVaultSecrets) Update ¶
func (c *FakeVaultSecrets) Update(vaultSecret *v1alpha1.VaultSecret) (result *v1alpha1.VaultSecret, err error)
Update takes the representation of a vaultSecret and updates it. Returns the server's representation of the vaultSecret, and an error, if there is any.
func (*FakeVaultSecrets) Watch ¶
func (c *FakeVaultSecrets) Watch(opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested vaultSecrets.