Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RandomSecretLister ¶
type RandomSecretLister interface {
// List lists all RandomSecrets in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.RandomSecret, err error)
// RandomSecrets returns an object that can list and get RandomSecrets.
RandomSecrets(namespace string) RandomSecretNamespaceLister
RandomSecretListerExpansion
}
RandomSecretLister helps list RandomSecrets.
func NewRandomSecretLister ¶
func NewRandomSecretLister(indexer cache.Indexer) RandomSecretLister
NewRandomSecretLister returns a new RandomSecretLister.
type RandomSecretListerExpansion ¶
type RandomSecretListerExpansion interface{}
RandomSecretListerExpansion allows custom methods to be added to RandomSecretLister.
type RandomSecretNamespaceLister ¶
type RandomSecretNamespaceLister interface {
// List lists all RandomSecrets in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.RandomSecret, err error)
// Get retrieves the RandomSecret from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.RandomSecret, error)
RandomSecretNamespaceListerExpansion
}
RandomSecretNamespaceLister helps list and get RandomSecrets.
type RandomSecretNamespaceListerExpansion ¶
type RandomSecretNamespaceListerExpansion interface{}
RandomSecretNamespaceListerExpansion allows custom methods to be added to RandomSecretNamespaceLister.
type VaultSecretLister ¶
type VaultSecretLister interface {
// List lists all VaultSecrets in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.VaultSecret, err error)
// VaultSecrets returns an object that can list and get VaultSecrets.
VaultSecrets(namespace string) VaultSecretNamespaceLister
VaultSecretListerExpansion
}
VaultSecretLister helps list VaultSecrets.
func NewVaultSecretLister ¶
func NewVaultSecretLister(indexer cache.Indexer) VaultSecretLister
NewVaultSecretLister returns a new VaultSecretLister.
type VaultSecretListerExpansion ¶
type VaultSecretListerExpansion interface{}
VaultSecretListerExpansion allows custom methods to be added to VaultSecretLister.
type VaultSecretNamespaceLister ¶
type VaultSecretNamespaceLister interface {
// List lists all VaultSecrets in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.VaultSecret, err error)
// Get retrieves the VaultSecret from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.VaultSecret, error)
VaultSecretNamespaceListerExpansion
}
VaultSecretNamespaceLister helps list and get VaultSecrets.
type VaultSecretNamespaceListerExpansion ¶
type VaultSecretNamespaceListerExpansion interface{}
VaultSecretNamespaceListerExpansion allows custom methods to be added to VaultSecretNamespaceLister.